//  Copyright 2019 Kakao Corp.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import UIKit
import KakaoPartnerSDKUser

extension Array where Element : ParamItem {
    func requestParam(key:String) -> AgeCriteria? {
        guard let paramItem = paramItem(key:key) else { return nil }
        
        switch paramItem.value {
        case .singleSelectableItem(let values):
            return paramItem.selectedIndex
                .map ({ index in
                    return values[index]
                })
                .compactMap({ ageCriteria in
                    return AgeCriteria(rawValue: ageCriteria)
                }).first
        default:
            break
        }
        return nil
    }
    
    func requestParam(key: String) -> Int64? {
        guard let paramItem = paramItem(key: key) else { return nil }
        
        switch paramItem.value {
        case .editableText(let values):
            return Int64(values)
        default:
            return nil
        }
    }
}
